Welcome to PyNSN's documentation!
=================================

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   install
   api
   examples


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
